@@ -22,6 +22,7 @@
 #include "preparation.h"
 #include "read-regex.h"
 #include "regex-morph.h"
+#include "resources.h"
 #include "sat-solver/sat-encoder.h"
 #include "corpus/corpus.h"
 #include "spellcheck.h"
@@ -619,8 +620,6 @@ static void post_process_linkages(Sentence sent, Parse_Options opts)
 	}
 
 #ifdef USE_FAT_LINKAGES
-	only_canonical_allowed = !(overflowed || (N_linkages_found > 2*opts->linkage_limit));
-#endif /* USE_FAT_LINKAGES */
 	/* When we're processing only a small subset of the linkages,
 	 * don't worry about restricting the set we consider to be
 	 * canonical ones.  In the extreme case where we are only
@@ -628,6 +627,9 @@ static void post_process_linkages(Sentence sent, Parse_Options opts)
 	 * that we'll hit two symmetric variants of the same linkage
 	 * anyway.
 	 */
+	only_canonical_allowed = !(overflowed || (N_linkages_found > 2*opts->linkage_limit));
+#endif /* USE_FAT_LINKAGES */
+
 	/* (optional) first pass: just visit the linkages */
 	/* The purpose of these two passes is to make the post-processing
 	 * more efficient.  Because (hopefully) by the time you do the
@@ -636,8 +638,7 @@ static void post_process_linkages(Sentence sent, Parse_Options opts)
 	 */
 	if (sent->length >= opts->twopass_length)
 	{
-		for (in=0; (in < N_linkages_alloced) &&
-				   (!resources_exhausted(opts->resources)); in++)
+		for (in=0; in < N_linkages_alloced; in++)
 		{
 			extract_links(indices[in], sent->null_count, sent->parse_info);
 #ifdef USE_FAT_LINKAGES
@@ -651,6 +652,7 @@ static void post_process_linkages(Sentence sent, Parse_Options opts)
 			{
 				analyze_thin_linkage(sent, opts, PP_FIRST_PASS);
 			}
+			if ((9 == in%10) && resources_exhausted(opts->resources)) break;
 		}
 	}
 
@@ -659,8 +661,7 @@ static void post_process_linkages(Sentence sent, Parse_Options opts)
 #ifdef USE_FAT_LINKAGES
 	N_thin_linkages = 0;
 #endif /* USE_FAT_LINKAGES */
-	for (in=0; (in < N_linkages_alloced) &&
-			   (!resources_exhausted(opts->resources)); in++)
+	for (in=0; in < N_linkages_alloced; in++)
 	{
 		Linkage_info *lifo = &link_info[N_linkages_post_processed];
 		extract_links(indices[in], sent->null_count, sent->parse_info);
@@ -691,6 +692,7 @@ static void post_process_linkages(Sentence sent, Parse_Options opts)
 		lifo->index = indices[in];
 		lg_corpus_score(sent, lifo);
 		N_linkages_post_processed++;
+		if ((9 == in%10) && resources_exhausted(opts->resources)) break;
 	}
 
 	print_time(opts, "Postprocessed all linkages");
@@ -1471,6 +1473,7 @@ int linkage_compute_union(Linkage linkage)
 
 int linkage_get_num_sublinkages(const Linkage linkage)
 {
+	if (!linkage) return 0;
 #ifdef USE_FAT_LINKAGES
 	return linkage->num_sublinkages;
 #else
@@ -1480,21 +1483,26 @@ int linkage_get_num_sublinkages(const Linkage linkage)
 
 int linkage_get_num_words(const Linkage linkage)
 {
+	if (!linkage) return 0;
 	return linkage->num_words;
 }
 
 int linkage_get_num_links(const Linkage linkage)
 {
 #ifdef USE_FAT_LINKAGES
-	int current = linkage->current;
+	int current;
+	if (!linkage) return 0;
+	current = linkage->current;
 	return linkage->sublinkage[current].num_links;
 #else
+	if (!linkage) return 0;
 	return linkage->sublinkage.num_links;
 #endif /* USE_FAT_LINKAGES */
 }
 
-static inline int verify_link_index(const Linkage linkage, int index)
+static inline Boolean verify_link_index(const Linkage linkage, int index)
 {
+	if (!linkage) return FALSE;
 	if ((index < 0) ||
 #ifdef USE_FAT_LINKAGES
 		(index >= linkage->sublinkage[linkage->current].num_links))
@@ -1502,9 +1510,9 @@ static inline int verify_link_index(const Linkage linkage, int index)
 		(index >= linkage->sublinkage.num_links))
 #endif /* USE_FAT_LINKAGES */
 	{
-		return 0;
+		return FALSE;
 	}
-	return 1;
+	return TRUE;
 }
 
 int linkage_get_link_length(const Linkage linkage, int index)
@@ -1621,6 +1629,7 @@ const char * linkage_get_disjunct_str(const Linkage linkage, int w)
 {
 	Disjunct *dj;
 
+	if (NULL == linkage) return "";
 	if (NULL == linkage->info->disjunct_list_str)
 	{
 		lg_compute_disjunct_strings(linkage->sent, linkage->info);
@@ -1654,6 +1663,7 @@ double linkage_get_disjunct_corpus_score(const Linkage linkage, int w)
 
 const char * linkage_get_word(const Linkage linkage, int w)
 {
+	if (!linkage) return NULL;
 	return linkage->word[w];
 }
 
