@@ -40,7 +40,7 @@ static inline char * deinflect(const char * str)
 	if (!p || (p == str)) return strdup(str);
 
 	len = p - str;
-	s = malloc(len + 1);
+	s = (char *)malloc(len + 1);
 	strncpy(s, str, len);
 	s[len] = '\0';
 	return s;
@@ -175,7 +175,7 @@ dictionary_six(const char * lang, const char * dict_name,
  */
 static Dictionary
 dictionary_six_str(const char * lang,
-                const wchar_t * input,
+                const char * input,
                 const char * dict_name,
                 const char * pp_name, const char * cons_name,
                 const char * affix_name, const char * regex_name)
@@ -193,6 +193,7 @@ dictionary_six_str(const char * lang,
 	t = strrchr (lang, '/');
 	if (t) dict->lang = string_set_add(t+1, dict->string_set);
 	dict->name = string_set_add(dict_name, dict->string_set);
+	dict->version = NULL;
 
 	dict->max_cost = 1000;
 	dict->num_entries = 0;
@@ -294,7 +295,7 @@ dictionary_six(const char * lang, const char * dict_name,
 {
 	Dictionary dict;
 
-	wchar_t* input = get_file_contents(dict_name);
+	char* input = get_file_contents(dict_name);
 	if (NULL == input)
 	{
 		prt_error("Error: Could not open dictionary %s", dict_name);
@@ -370,49 +371,20 @@ Dictionary dictionary_create_from_utf8(const char * input)
 {
 	Dictionary dictionary = NULL;
 	char * lang;
-	wchar_t *winput, *wp;
-	size_t len;
-	const char *p;
-	int cv;
 
 	init_memusage();
 
-	/* Convert input string to wide chars. This is needed for locale
-	 * compatibility with the dictionary read routines. */
-	len = strlen(input) + 1;
-	winput = (wchar_t*) malloc(len * sizeof(wchar_t));
-
-	p = input;
-	wp = winput;
-	while (1)
-	{
-		cv = mbtowc(wp, p, 8);
-		if (-1 == cv)
-		{
-			prt_error("Error: Conversion failure!");
-		goto failure;
-		}
-		if (0 == cv)
-			break;
-		p += cv;
-		wp++;
-	}
-
-
 	lang = get_default_locale();
 	if (lang && *lang) {
-		dictionary = dictionary_six_str(lang, winput, "string",
+		dictionary = dictionary_six_str(lang, input, "string",
 		                                NULL, NULL, NULL, NULL);
 		free(lang);
 	} else {
 		/* Default to en when locales are broken (e.g. WIN32) */
-		dictionary = dictionary_six_str("en", winput, "string",
+		dictionary = dictionary_six_str("en", input, "string",
 		                                NULL, NULL, NULL, NULL);
 	}
 
-failure:
-	free(winput);
-
 	return dictionary;
 }
 
