@@ -76,9 +76,6 @@ static void setup_panic_parse_options(Parse_Options opts)
 	parse_options_set_min_null_count(opts, 1);
 	parse_options_set_max_null_count(opts, MAX_SENTENCE);
 	parse_options_set_max_parse_time(opts, 60);
-#ifdef USE_FAT_LINKAGES
-	parse_options_set_use_fat_links(opts, FALSE);
-#endif /* USE_FAT_LINKAGES */
 	parse_options_set_islands_ok(opts, TRUE);
 	parse_options_set_short_length(opts, 6);
 	parse_options_set_all_short_connectors(opts, TRUE);
@@ -136,9 +133,6 @@ static per_thread_data * init(JNIEnv *env, jclass cls)
 	ptd = (per_thread_data *) malloc(sizeof(per_thread_data));
 	memset(ptd, 0, sizeof(per_thread_data));
 
-	ptd->panic_parse_opts = parse_options_create();
-	setup_panic_parse_options(ptd->panic_parse_opts);
-
 	ptd->opts = parse_options_create();
 	parse_options_set_disjunct_costf(ptd->opts, 3.0f);
 	parse_options_set_max_sentence_length(ptd->opts, 170);
@@ -148,6 +142,10 @@ static per_thread_data * init(JNIEnv *env, jclass cls)
 	parse_options_set_verbosity(ptd->opts,0);
 	parse_options_set_spell_guess(ptd->opts, FALSE);
 
+	parse_options_set_panic_mode(ptd->opts, TRUE);
+	ptd->panic_parse_opts = parse_options_create();
+	setup_panic_parse_options(ptd->panic_parse_opts);
+
 	ptd->dict = dictionary_create_lang(in_language);
 	if (!ptd->dict) throwException(env, "Error: unable to open dictionary");
 	else test();
@@ -261,9 +259,6 @@ static void jParse(JNIEnv *env, per_thread_data *ptd, char* inputString)
 	parse_options_set_disjunct_costf(opts, 2.0f);
 	parse_options_set_min_null_count(opts, 0);
 	parse_options_set_max_null_count(opts, 0);
-#ifdef USE_FAT_LINKAGES
-	parse_options_set_use_fat_links(opts, FALSE);
-#endif /* USE_FAT_LINKAGES */
 	parse_options_reset_resources(opts);
 
 	ptd->num_linkages = sentence_parse(ptd->sent, ptd->opts);
@@ -280,25 +275,28 @@ static void jParse(JNIEnv *env, per_thread_data *ptd, char* inputString)
 		}
 	}
 
-	if (parse_options_timer_expired(opts))
+	if (jverbosity > 0)
 	{
-		if (jverbosity > 0) prt_error("Warning: JNI: Timer is expired!\n");
-	}
-	if (parse_options_memory_exhausted(opts))
-	{
-		if (jverbosity > 0) prt_error("Warning: JNI: Memory is exhausted!\n");
+		if (parse_options_timer_expired(opts))
+			prt_error("Warning: JNI: Timer is expired!\n");
+
+		if (parse_options_memory_exhausted(opts))
+			prt_error("Warning: JNI: Memory is exhausted!\n");
 	}
 
 	if ((ptd->num_linkages == 0) &&
-	    parse_options_resources_exhausted(opts))
+	    parse_options_resources_exhausted(opts) &&
+	    parse_options_get_panic_mode(opts))
 	{
 		parse_options_print_total_time(opts);
 		if (jverbosity > 0) prt_error("Warning: JNI: Entering \"panic\" mode...\n");
 		parse_options_reset_resources(ptd->panic_parse_opts);
 		parse_options_set_verbosity(ptd->panic_parse_opts, jverbosity);
 		ptd->num_linkages = sentence_parse(ptd->sent, ptd->panic_parse_opts);
-		if (parse_options_timer_expired(ptd->panic_parse_opts)) {
-			if (jverbosity > 0) prt_error("Error: JNI: Timer is expired!\n");
+		if (jverbosity > 0)
+		{
+			if (parse_options_timer_expired(ptd->panic_parse_opts)) 
+				prt_error("Error: JNI: Panic timer is expired!\n");
 		}
 	}
 }
@@ -311,7 +309,9 @@ static void makeLinkage(per_thread_data *ptd)
 			linkage_delete(ptd->linkage);
 
 		ptd->linkage = linkage_create(ptd->cur_linkage,ptd->sent,ptd->opts);
+
 #ifdef USE_FAT_LINKAGES
+		if (!ptd->linkage) return;
 		linkage_compute_union(ptd->linkage);
 		linkage_set_current_sublinkage(ptd->linkage,
 		                        linkage_get_num_sublinkages(ptd->linkage)-1);
@@ -520,11 +520,13 @@ Java_org_linkgrammar_LinkGrammar_getLinkageSense(JNIEnv *env,
 {
 	per_thread_data *ptd = get_ptd(env, cls);
 	Linkage lkg = ptd->linkage;
-	Linkage_info *lifo = lkg->info;
+	Linkage_info *lifo;
 	Sense *sns;
 	const char * w = NULL;
 	jstring js;
 
+	if (!lkg) return NULL;
+	lifo = lkg->info;
 	lg_corpus_linkage_senses(lkg);
 	sns = lg_get_word_sense(lifo, i);
 	while ((0 < j) && sns)
@@ -547,10 +549,12 @@ Java_org_linkgrammar_LinkGrammar_getLinkageSenseScore(JNIEnv *env,
 {
 	per_thread_data *ptd = get_ptd(env, cls);
 	Linkage lkg = ptd->linkage;
-	Linkage_info *lifo = lkg->info;
+	Linkage_info *lifo = lkg;
 	Sense *sns;
 	double score = 0.0;
 
+	if (!lkg) return 0.0;
+	lifo = lkg->info;
 	sns = lg_get_word_sense(lifo, i);
 	while ((0 < j) && sns)
 	{
