@@ -15,6 +15,7 @@
 #define _STRUCTURES_H_
 
 #include "api-types.h"
+#include "read-dict.h"  /* For Exp, Exp_list */
 #include "utilities.h"  /* Needed for inline defn in Windows */
 
 /*
@@ -67,6 +68,7 @@
     sentence[].string because it contains the suffixes.  It differs from
     chosen_disjunct[].string in that the idiom symbols have been removed.
 
+#ifdef USE_FAT_LINKAGES
  has_fat_down[]
     An array of chars, one for each word.  TRUE if there is a fat link
     down from this word, FALSE otherwise.  (Only set if there is at least
@@ -76,6 +78,7 @@
  is_conjunction[]
     An array of chars, one for each word.  TRUE if the word is a conjunction
     ("and", "or", "nor", or "but" at the moment).  False otherwise. 
+#endif USE_FAT_LINKAGES 
 */
 
 
@@ -89,18 +92,23 @@
 /* Upper bound on the cost of any connector. */
 #define MAX_CONNECTOR_COST 1000.0f
 
-#define LEFT_WALL_DISPLAY  ("LEFT-WALL")   /* the string to use to show the wall */
-#define LEFT_WALL_SUPPRESS ("Wd") /* If this connector is used on the wall, */
-                                  /* then suppress the display of the wall  */
-                                  /* bogus name to prevent ever suppressing */
-#define RIGHT_WALL_DISPLAY  ("RIGHT-WALL")   /* the string to use to show the wall */
-#define RIGHT_WALL_SUPPRESS ("RW") /* If this connector is used on the wall, */
-
 /* The following define the names of the special strings in the dictionary. */
 #define LEFT_WALL_WORD   ("LEFT-WALL")
 #define RIGHT_WALL_WORD  ("RIGHT-WALL")
-#define POSTPROCESS_WORD ("POSTPROCESS")
-#define ANDABLE_CONNECTORS_WORD ("ANDABLE-CONNECTORS")
+#define EMPTY_WORD  ("=.zzz")
+
+#ifdef USE_FAT_LINKAGES
+  #define ANDABLE_CONNECTORS_WORD ("ANDABLE-CONNECTORS")
+
+  /* conditional compiling flags */
+  #define PLURALIZATION
+      /* If defined, Turns on the pluralization operation in        */
+      /* "and", "or" and "nor" */
+
+  #define NORMAL_LABEL  (-1) /* used for normal connectors            */
+                             /* the labels >= 0 are used by fat links */
+#endif /* USE_FAT_LINKAGES */
+
 #define UNLIMITED_CONNECTORS_WORD ("UNLIMITED-CONNECTORS")
 
 #define UNKNOWN_WORD     ("UNKNOWN-WORD")
@@ -115,20 +123,10 @@
 #define MAX_DISJUNCT_COST 10000
 
 /* conditional compiling flags */
-#define PLURALIZATION
-      /* If defined, Turns on the pluralization operation in        */
-      /* "and", "or" and "nor" */
 #define INFIX_NOTATION
       /* If defined, then we're using infix notation for the dictionary */
       /* otherwise we're using prefix notation */
 
-#define DOWN_priority 2
-#define UP_priority   1
-#define THIN_priority 0
-
-#define NORMAL_LABEL  (-1) /* used for normal connectors            */
-                           /* the labels >= 0 are used by fat links */
-
 #define UNLIMITED_LEN 255
 #define SHORT_LEN 6
 #define NO_WORD 255
@@ -145,6 +143,7 @@ typedef signed __int64 s64; /* signed 64-bit integer, even on 32-bit cpus */
 struct Tokenizer_struct
 {
 	String_set  * string_set;
+	const char * unsplit_word;
 	const char ** pref_alternatives;
 	const char ** stem_alternatives;
 	const char ** suff_alternatives;
@@ -152,10 +151,18 @@ struct Tokenizer_struct
 
 typedef struct Tokenizer_struct Tokenizer;
 
+#ifdef USE_FAT_LINKAGES
+typedef enum
+{
+	THIN_priority,
+	UP_priority,
+	DOWN_priority
+} Priority;
+#endif /* USE_FAT_LINKAGES */
+
 struct Connector_struct
 {
-    short label;
-    short hash;
+    int hash;
     unsigned char word;
                    /* The nearest word to my left (or right) that
                       this could connect to.  Computed by power pruning */
@@ -166,14 +173,16 @@ struct Connector_struct
                      this is strictly a funcion of the connector
                      name, efficiency is the only reason to store
                      this.  If no limit, the value is set to 255. */
-    char priority;/* one of the three priorities above */
     char multi;   /* TRUE if this is a multi-connector */
+#ifdef USE_FAT_LINKAGES
+    Priority priority;/* one of the three priorities above */
+    short label;
+#endif /* USE_FAT_LINKAGES */
     Connector * next;
     const char * string;
 
     /* Hash table next pointer, used only during pruning. */
     Connector * tableNext;
-    const char * prune_string;
 };
 
 static inline void connector_set_string(Connector *c, const char *s)
@@ -212,44 +221,13 @@ struct X_node_struct
 
 struct Word_struct
 {
+    const char *unsplit_word;
     const char **alternatives;
     X_node * x;      /* sentence starts out with these */
     Disjunct * d;    /* eventually these get generated */
     Boolean firstupper;
 };
 
-/** 
- * Types of Exp_struct structures
- */
-#define OR_type 0
-#define AND_type 1
-#define CONNECTOR_type 2
-
-/** 
- * The E_list and Exp structures defined below comprise the expression
- * trees that are stored in the dictionary.  The expression has a type
- * (AND, OR or TERMINAL).  If it is not a terminal it has a list
- * (an E_list) of children.
- */
-struct Exp_struct
-{
-    Exp * next; /* Used only for mem management,for freeing */
-    char type;  /* One of three types, see above */
-    char dir;   /* '-' means to the left, '+' means to right (for connector) */
-    char multi; /* TRUE if a multi-connector (for connector)  */
-    union {
-        E_list * l;           /* only needed for non-terminals */
-        const char * string;  /* only needed if it's a connector */
-    } u;
-    float cost;   /* The cost of using this expression.
-                     Only used for non-terminals */
-};
-
-struct E_list_struct
-{
-    E_list * next;
-    Exp * e;
-};
 
 /* The structure below stores a list of dictionary word files. */
 struct Word_file_struct
@@ -259,19 +237,6 @@ struct Word_file_struct
     Word_file * next;
 };
 
-/** 
- * The dictionary is stored as a binary tree comprised of the following
- * nodes.  A list of these (via right pointers) is used to return
- * the result of a dictionary lookup.
- */
-struct Dict_node_struct
-{
-    const char * string;  /* the word itself */
-    Word_file * file;    /* the file the word came from (NULL if dict file) */
-    Exp       * exp;
-    Dict_node *left, *right;
-};
-
 /* The regexs are stored as a linked list of the following nodes. */
 struct Regex_node_s
 {
@@ -303,6 +268,7 @@ struct PP_node_struct
 
 /* Davy added these */
 
+#ifdef USE_FAT_LINKAGES
 typedef struct Andlist_struct Andlist;
 struct Andlist_struct
 {
@@ -314,6 +280,7 @@ struct Andlist_struct
     int outside_word[MAX_SENTENCE];
     int cost;
 };
+#endif /* USE_FAT_LINKAGES */
 
 /** 
  * This is for building the graphs of links in post-processing and 
@@ -322,19 +289,24 @@ struct Andlist_struct
 struct Linkage_info_struct
 {
     int index;
-    Boolean fat;
-    Boolean canonical;
 #ifdef USE_FAT_LINKAGES
+    Boolean canonical;
+    Boolean fat;
     Boolean improper_fat_linkage;
-#endif /* USE_FAT_LINKAGES */
     Boolean inconsistent_domains;
+    short and_cost;
+#endif /* USE_FAT_LINKAGES */
     short N_violations;
-    short null_cost, unused_word_cost, and_cost, link_cost;
+    short null_cost;
+    short unused_word_cost;
+    short link_cost;
     float disjunct_cost;
     double corpus_cost;
     int island[MAX_SENTENCE];
     size_t nwords;
+#ifdef USE_FAT_LINKAGES
     Andlist * andlist;
+#endif /* USE_FAT_LINKAGES */
     char **disjunct_list_str;
 #ifdef USE_CORPUS
     Sense **sense_list;
@@ -349,11 +321,13 @@ struct List_o_links_struct
     List_o_links * next;
 };
 
+#ifdef USE_FAT_LINKAGES
 /* These parameters tell power_pruning, to tell whether this is before
  * or after generating and disjuncts.  GENTLE is before RUTHLESS is 
  * after.
  */
 #define GENTLE 1
+#endif /* USE_FAT_LINKAGES */
 #define RUTHLESS 0
 
 typedef struct Parse_choice_struct Parse_choice;
