@@ -181,10 +181,10 @@ static void issue_sentence_word(Sentence sent, const char * s, Boolean quote_fou
 	size_t len = sent->length;
 	if (*s == '\0') return;
 
-	sent->post_quote = realloc(sent->post_quote, (len+1) * sizeof(Boolean));
+	sent->post_quote = (Boolean *)realloc(sent->post_quote, (len+1) * sizeof(Boolean));
 	sent->post_quote[len] = quote_found;
 
-	sent->word = realloc(sent->word, (len+1) * sizeof(Word));
+	sent->word = (Word *)realloc(sent->word, (len+1) * sizeof(Word));
 	sent->word[len].x = NULL;
 	sent->word[len].d = NULL;
 
@@ -214,7 +214,7 @@ static size_t altlen(const char **arr)
 
 static const char ** resize_alts(const char **arr, size_t len)
 {
-	arr = realloc(arr, (len+2) * sizeof(const char *));
+	arr = (const char **)realloc(arr, (len+2) * sizeof(const char *));
 	arr[len+1] = NULL;
 	return arr;
 }
@@ -302,10 +302,10 @@ static Boolean issue_alternatives(Sentence sent, Boolean quote_found)
 	{
 		size_t i;
 
-		sent->post_quote = realloc(sent->post_quote, (len+1) * sizeof(Boolean));
+		sent->post_quote = (Boolean *)realloc(sent->post_quote, (len+1) * sizeof(Boolean));
 		sent->post_quote[len] = quote_found;
 
-		sent->word = realloc(sent->word, (len+1) * sizeof(Word));
+		sent->word = (Word *)realloc(sent->word, (len+1) * sizeof(Word));
 		sent->word[len].x = NULL;
 		sent->word[len].d = NULL;
 		sent->word[len].unsplit_word = NULL;
@@ -325,10 +325,10 @@ static Boolean issue_alternatives(Sentence sent, Boolean quote_found)
 
 	if (stemlen)
 	{
-		sent->post_quote = realloc(sent->post_quote, (len+1) * sizeof(Boolean));
+		sent->post_quote = (Boolean *)realloc(sent->post_quote, (len+1) * sizeof(Boolean));
 		sent->post_quote[len] = preflen ? FALSE : quote_found;
 
-		sent->word = realloc(sent->word, (len+1) * sizeof(Word));
+		sent->word = (Word *)realloc(sent->word, (len+1) * sizeof(Word));
 		sent->word[len].x = NULL;
 		sent->word[len].d = NULL;
 		sent->word[len].unsplit_word = tokenizer->unsplit_word;
@@ -352,10 +352,10 @@ static Boolean issue_alternatives(Sentence sent, Boolean quote_found)
 
 	if (sufflen)
 	{
-		sent->post_quote = realloc(sent->post_quote, (len+1) * sizeof(Boolean));
+		sent->post_quote = (Boolean *)realloc(sent->post_quote, (len+1) * sizeof(Boolean));
 		sent->post_quote[len] = FALSE;
 
-		sent->word = realloc(sent->word, (len+1) * sizeof(Word));
+		sent->word = (Word *)realloc(sent->word, (len+1) * sizeof(Word));
 		sent->word[len].x = NULL;
 		sent->word[len].d = NULL;
 		sent->word[len].unsplit_word = NULL;
@@ -488,7 +488,7 @@ static Boolean suffix_split(Tokenizer *tokenizer, Dictionary dict,
 			if ((i < s_strippable) &&
 			    find_word_in_dict(dict, newword))
 			{
-				if (1 < verbosity)
+				if (2 < verbosity)
 					printf("Splitting word into two: %s-%s\n", newword, suffix[i]);
 
 				add_suffix_alternatives(tokenizer, newword, suffix[i]);
@@ -508,7 +508,7 @@ static Boolean suffix_split(Tokenizer *tokenizer, Dictionary dict,
 						newword[sz] = '\0';
 						if (find_word_in_dict(dict, newword))
 						{
-							if (verbosity>1)
+							if (2 < verbosity)
 							{
 								if (i < s_strippable)
 									printf("Splitting word into three: %s-%s-%s\n",
@@ -610,6 +610,26 @@ static void separate_word(Sentence sent, Parse_Options opts,
 		return;
 	}
 
+	/* Ugly hack: "let's" is in the english dict, but "Let's" is not. Thus,
+	 * sentences beginning with upper-case let's fail, while lower-case
+	 * pass! Again, need to fix this, since let's can also split into two ...
+	 * XXX should also check to see if its after a colon...
+	 */
+	if (((dict->left_wall_defined && sent->length == 1) ||
+	    (!dict->left_wall_defined && sent->length == 0)) &&
+	    is_utf8_upper(word))
+	{
+		char temp_word[MAX_WORD+1];
+		downcase_utf8_str(temp_word, word, MAX_WORD);
+		word_is_in_dict = find_word_in_dict (dict, temp_word);
+		if (word_is_in_dict)
+		{
+			const char *lc = string_set_add(temp_word, sent->string_set);
+			issue_sentence_word(sent, lc, quote_found);
+			return;
+		}
+	}
+
 	/* Set up affix tables.  */
 	if (dict->affix_table != NULL)
 	{
@@ -1199,7 +1219,7 @@ void build_sentence_expressions(Sentence sent, Parse_Options opts)
 					if (is_entity(sent->dict,s) ||
 					    is_common_entity(sent->dict,lc))
 					{
-						if (1 < verbosity)
+						if (2 < verbosity)
 						{
 							printf ("Info: First word: %s entity=%d common=%d\n", 
 								s, is_entity(sent->dict,s), 
@@ -1214,7 +1234,7 @@ void build_sentence_expressions(Sentence sent, Parse_Options opts)
 					}
 					else
 					{
-						if (1 < verbosity)
+						if (2 < verbosity)
 						{
 							printf("Info: First word: %s downcase only\n", lc);
 						}
