@@ -108,9 +108,6 @@ char * strndup (const char *str, size_t size);
 #define iswdigit  isdigit
 #define iswspace  isspace
 #define wchar_t   char
-#define wint_t    unsigned int  /* I think ?? not sure */
-#define fgetwc    fgetc
-#define WEOF      EOF
 #define towlower  tolower
 #define towupper  toupper
 #endif /* CYGWIN_VERSION_DLL_MAJOR < 1007 */
@@ -118,6 +115,13 @@ char * strndup (const char *str, size_t size);
 
 #endif /* _WIN32 */
 
+/* MSVC isspace asserts in debug mode, and mingw sometime returns true, when passed utf8 */
+#if defined(_MSC_VER) || defined(__MINGW32__)
+  #define lg_isspace(c) ((0 < c) && (c < 127) && isspace(c))
+#else
+  #define lg_isspace isspace
+#endif
+
 #if defined(__sun__)
 int strncasecmp(const char *s1, const char *s2, size_t n);
 /* This does not appear to be in string.h header file in sunos
@@ -161,8 +165,11 @@ static inline size_t utf8_strlen(const char *s)
 {
 	mbstate_t mbss;
 	memset(&mbss, 0, sizeof(mbss));
-
+#if defined(_MSC_VER) || defined(__MINGW32__)
+	return MultiByteToWideChar(CP_UTF8, 0, s, -1, NULL, 0)-1;
+#else
 	return mbsrtowcs(NULL, &s, 0, &mbss);
+#endif
 }
 
 /**
@@ -267,7 +274,7 @@ static inline int utf8_upper_match(const char * s, const char * t)
 	return TRUE;
 }
 
-int wctomb_check(char *s, wchar_t wc, mbstate_t *ps);
+int wctomb_check(char *s, wchar_t wc);
 void downcase_utf8_str(char *to, const char * from, size_t usize);
 void upcase_utf8_str(char *to, const char * from, size_t usize);
 
@@ -303,7 +310,7 @@ void * object_open(const char *filename,
                    void * (*opencb)(const char *, void *),
                    void * user_data);
 
-wchar_t * get_file_contents(const char *filename);
+char * get_file_contents(const char *filename);
 
 /**
  * Returns the smallest power of two that is at least i and at least 1
