@@ -1,5 +1,5 @@
 /*************************************************************************/
-/* Copyright (c) 2012 Linas Vepstas <linasvepstas@gmail.com>             */
+/* Copyright (c) 2012, 2013 Linas Vepstas <linasvepstas@gmail.com>       */
 /* All rights reserved                                                   */
 /*                                                                       */
 /* Use of the Viterbi parsing system is subject to the terms of the      */
@@ -38,8 +38,8 @@ bool conn_match(const string& ls, const string& rs)
 {
 	char ldir = *ls.rbegin();
 	char rdir = *rs.rbegin();
-	assert (ldir == '+' or ldir == '-', "Bad word direction");
-	assert (rdir == '+' or rdir == '-', "Bad word direction");
+	assert (ldir == '+' or ldir == '-', "Bad word direction (l)");
+	assert (rdir == '+' or rdir == '-', "Bad word direction (r)");
 
 	// Direction signs must couple.
 	if ('+' == ldir and '-' != rdir) return false;
@@ -48,12 +48,15 @@ bool conn_match(const string& ls, const string& rs)
 	// Captial letters must match. Wildcards match anything lower-case.
 	string::const_iterator lp = ls.begin();
 	string::const_iterator rp = rs.begin();
-	size_t len = -1 + min(ls.size(), rs.size());
+	size_t lslen = ls.size();
+	size_t rslen = rs.size();
+	size_t minlen = min(lslen, rslen);
+	size_t len = minlen - 1;  // -1 for direction
 	while (0 < len)
 	{
 		if (*lp != *rp)
 		{
-			// All upper-case letters must match!
+			// All upper-case letters must match exactly!
 			if (isupper(*lp) or isupper(*rp)) return false;
 			// Wild-card matches anything.
 			if ('*' != *lp and '*' != *rp) return false;
@@ -62,6 +65,9 @@ bool conn_match(const string& ls, const string& rs)
 		rp++;
 		len--;
 	}
+	// If the longer string is sill upper-case .. ouch
+	if ((minlen < lslen) and isupper(*lp)) return false;
+	if ((minlen < rslen) and isupper(*rp)) return false;
 
 	return true;
 }
@@ -142,7 +148,7 @@ bool is_optional(Atom *a)
 
 // ===================================================================
 
-// Utility for below.
+// Utility for below. See description given there.
 static Atom* trim_left_pointers(Atom* a)
 {
 	Connector* ct = dynamic_cast<Connector*>(a);
@@ -153,12 +159,17 @@ static Atom* trim_left_pointers(Atom* a)
 		char dir = ct->get_direction();
 		if ('-' == dir) return NULL;
 		if ('+' == dir) return a;
-		assert(0, "Bad word direction");
+		assert(0, "Bad word direction (t)");
 	}
 
 	AtomType ty = a->get_type();
 	assert (OR == ty or AND == ty, "Must be boolean junction");
 
+	// Note: With the new DNF style of processing esewhere in the code,
+	// it will never be the case that the block of code will be hit.
+	// None-the-less, the code below works great for arbitrarily-nested
+	// connector sets (i.e. sets that are not in any normal form) and
+	// so its left here in case you need it.
 	if (OR == ty)
 	{
 		OutList new_ol;
@@ -219,20 +230,19 @@ static Atom* trim_left_pointers(Atom* a)
 	}
 
 	if (0 == new_ol.size())
-		return NULL;
+		return new And();
 
 	if (1 == new_ol.size())
 		return new_ol[0];
 
-	return new Link(AND, new_ol);
+	return new And(new_ol);
 }
 
 /// Trim away all optional left pointers (connectors with - direction)
 /// If there are any non-optional left-pointers, then return NULL.
 ///
-/// XXX Wait, I'm confused: it could also be null if everything
-/// was optional, and everything was left-facing, so everything got
-/// trimmed away... but that's OK, because ... ermmmm
+/// If all of the connectors were optional left-pointers, then they
+/// are all trimmed away, and a single, empty AND is returned.
 WordCset* cset_trim_left_pointers(WordCset* wrd_cset)
 {
 	Atom* trimmed = trim_left_pointers(wrd_cset->get_cset());
